// probtest.cpp : Defines the entry point for the console application.
//


#include "Probability.h"
#include "BinomialProbability.h"
#include "GeometricProbability.h"
#include "NegativeBinomialProbability.h"
#include "PoissonProbability.h"
#include "HyperGeometricProbability.h"
#include <iostream.h>
#include <iomanip.h>

void testGeometric();
void testNegativeBinomial();
void testPoisson();
void testHyperGeometric();
void testBinomial();

typedef Probability::RandomVariableType rvt;

int main(int argc, char* argv[])
{
	testGeometric();
	testNegativeBinomial();
	testPoisson();
	testHyperGeometric();
	testBinomial();
	return 0;
}

void testBinomial()
{
	double p = .50;
	int N = 8;
	int Y ;
	cout << "Binomial test..." << endl;
	for(Y=0;Y<=N;Y++)
	{
		BinomialProbability nbp(N,Y,p);
		cout << nbp.GetResult() << "  ";
	}
	cout << endl;
	cout << BinomialProbability(99,49,p, Probability::RandomVariableType::LESSTHANOREQUAL).GetResult();
	cout << endl;
}

void testHyperGeometric()
{
	int N = 20;
	int r = 4;
	int n = 5;
	int Y;
	cout << "HyperGeometric test..." << endl;
	for(Y=0 ; Y<= r; Y++)
	{
		HyperGeometricProbability hgp(N,n,Y,r);
		cout << hgp.GetResult() << " ";
	}
	cout << endl;
	cout << HyperGeometricProbability(N,n,2,r,Probability::RandomVariableType::GREATERTHANOREQUAL).GetResult();
	cout << endl;
}

void testPoisson()
{
	double lambda = 3;
	int Y ;
	cout << "Poisson test..."<<endl;
	for(Y=0; Y<8;Y++)
	{
		PoissonProbability pp(Y,lambda);
		cout << pp.GetResult() << "  " ;
	}
	cout << endl;
	cout << PoissonProbability(6,lambda, Probability::RandomVariableType::GREATERTHANOREQUAL).GetResult();
	cout << endl;
}

void testNegativeBinomial()
{
	double p = .20;
	int Y ;
	int r=3;
	cout << "Negative Binomial test..." << endl;
	for(Y=0;Y<8;Y++)
	{
		NegativeBinomialProbability nbp(Y,r,p);
		cout << nbp.GetResult() << "  ";
	}
	cout << endl;
	cout << NegativeBinomialProbability(5,3,p, Probability::RandomVariableType::EQUAL).GetResult();
	cout << endl;
}

void testGeometric()
{
	double p = .02;
	int Y; // from zero to 8;
	cout << "Geometric test..." << endl;
	for(Y=0;Y<8;Y++)
	{
		GeometricProbability gp(Y,p);
		cout  << gp.GetResult() << "  ";
	}
	cout << endl;
	// this answer should be .9604
	cout << GeometricProbability(3,p,Probability::RandomVariableType::GREATERTHANOREQUAL).GetResult();
	cout << endl;
}
